import unittest

from bootstrap_difflib.bootstrap_difflib import BootstrapHtmlDiff


class TestBootstrapDiffLib(unittest.TestCase):

    def setUp(self):
        self.differ = BootstrapHtmlDiff(bootstrap_source='/my_path')

    def test_make_table(self):
        self.assertIn('class="diff table"', self.differ.make_table(fromlines=['xyz'], tolines=['abc']))



from bootstrap_difflib.bootstrap_difflib import BootstrapHtmlDiff

print(__name__)
if __name__ == "__main__":
    toLines = ['This project was born out of the idea', 'Of wanting a slightly better', 'Looking Diff Table']
    fromLines = ['This project has been born out of the idea', 'Of wanting a slightly better', 'GUI']

    import os
    import webbrowser

    t = BootstrapHtmlDiff("https://stackpath.bootstrapcdn.com/bootstrap/4.1.1/css/bootstrap.min.css")
    path = os.path.abspath('temp.html')
    url = 'file://' + path
    html = t.make_file(toLines, fromLines)
    print(html)
    with open(path, 'w') as f:
        f.write(html)
    webbrowser.open(url)

    f.close()


import difflib

from bootstrap_difflib.utils import FormatDict


_file_template = """
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
          "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">

<html>

<head>
    <meta http-equiv="Content-Type"
          content="text/html; charset=%(charset)s" />
    <title></title>
    <link rel="stylesheet" type="text/css" href="%(bootstrap_source)s">
    <style type="text/css">%(styles)s
    </style>
</head>

<body>
    %(table)s%(legend)s
</body>

</html>"""

_styles = """
        .table td {padding: 0;}
        .table th {padding: 0;} 
        table.diff {font-family:Courier; border:medium;}
        .diff_header {background-color:#e0e0e0}
        td.diff_header {text-align:right}
        .diff_next {background-color:#c0c0c0}
        .diff_add {background-color:#aaffaa}
        .diff_chg {background-color:#ffff77}
        .diff_sub {background-color:#ffaaaa}"""

_table_template = """
    <table class="diff %(bootstrap_table_class)s" id="difflib_chg_%(prefix)s_top"
           cellspacing="0" cellpadding="0" rules="groups" >
        <colgroup></colgroup> <colgroup></colgroup> <colgroup></colgroup>
        <colgroup></colgroup> <colgroup></colgroup> <colgroup></colgroup>
        %(header_row)s
        <tbody>
%(data_rows)s        </tbody>
    </table>"""


class BootstrapHtmlDiff(difflib.HtmlDiff):
    """A simple wrapper for the DiffLib that makes it useful with Bootstrap."""
    _styles = _styles

    def __init__(self, bootstrap_source, bootstrap_table_class="table", *args, **kwargs):
        """
        Behaves exactly as the HtmlDiff class, but requires a Bootstrap source.

        :param bootstrap_source: URL to your bootstrap source.
        :param bootstrap_table_class: Name of the bootstrap class to use, defaults to table.
        :param args: See superclass
        :param kwargs: See superclass
        """
        self._file_template = _file_template % FormatDict(bootstrap_source=bootstrap_source)
        self._table_template = _table_template % FormatDict(bootstrap_table_class=bootstrap_table_class)
        super(BootstrapHtmlDiff, self).__init__(*args, **kwargs)
